import sys

from PyObjCTools.TestSupport import TestCase, min_os_level

if sys.maxsize > 2 ** 32:
    import ExecutionPolicy

    class TestEPDeveloperTool(TestCase):
        def test_constants(self):
            self.assertEqual(ExecutionPolicy.EPDeveloperToolStatusNotDetermined, 0)
            self.assertEqual(ExecutionPolicy.EPDeveloperToolStatusRestricted, 1)
            self.assertEqual(ExecutionPolicy.EPDeveloperToolStatusDenied, 2)
            self.assertEqual(ExecutionPolicy.EPDeveloperToolStatusAuthorized, 3)

        @min_os_level("10.15")
        def test_methods(self):
            self.assertArgIsBlock(
                ExecutionPolicy.EPDeveloperTool.requestDeveloperToolAccessWithCompletionHandler_,  # noqa: B950
                0,
                b"vZ",
            )



# This file is generated by objective.metadata
#
# Last update: Sat Mar 21 15:30:08 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$EPErrorDomain$"""
enums = """$EPDeveloperToolStatusAuthorized@3$EPDeveloperToolStatusDenied@2$EPDeveloperToolStatusNotDetermined@0$EPDeveloperToolStatusRestricted@1$EPErrorGeneric@1$EPErrorNotADeveloperTool@2$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"EPDeveloperTool",
        b"requestDeveloperToolAccessWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"Z"}},
                    }
                }
            }
        },
    )
    r(
        b"EPExecutionPolicy",
        b"addPolicyExceptionForURL:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import sys

from PyObjCTools.TestSupport import TestCase

if sys.maxsize > 2 ** 32:
    import ExecutionPolicy

    class TestEPErrors(TestCase):
        def test_constants(self):
            self.assertIsInstance(ExecutionPolicy.EPErrorDomain, str)

            self.assertEqual(ExecutionPolicy.EPErrorGeneric, 1)
            self.assertEqual(ExecutionPolicy.EPErrorNotADeveloperTool, 2)
